==> cobertura-diff-coverage-1.0.5.tgz: package/report.js <==

const fs = require("fs")

/**
 * generate the html report containing the dynamic scritps we need to read the json report
 *
 * @param uncoveredLinesReport: string
 */
function generateHtmlReport(uncoveredLinesReport) {

    const uncoveredLinesHtml = createHtmlFromJsonReport(uncoveredLinesReport)

    const reportString = `
    <!DOCTYPE html>
    <html>
    <head>
        <title> Use of JQuery to Add Edit Delete Table Row </title>
        <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.4.1/css/bootstrap.min.css">
        <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
        <script src="https://maxcdn.bootstrapcdn.com/bootstrap/3.4.1/js/bootstrap.min.js"></script>
        <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css" />
    </head>
    <body>
        <div class="container">
            <h2>Uncovered Lines and Branches</h2>
            <p class="font-weight-light">${new Date()}</p>
            <div id="uncovered">
                ${uncoveredLinesHtml}
            </div>
        </div>
    </body>
    </html>
    `
    fs.writeFileSync("cobertura-report.html", reportString);
}

function createHtmlFromJsonReport(uncoveredLinesReport) {
    var uncoveredLinesHtml = ``
    Object.keys(uncoveredLinesReport).forEach((filePath) => {
        var uncovLines = `<h5>Lines</h5>`
        uncoveredLinesReport[filePath].uncoveredLines.forEach((line) => {
            uncovLines += `<p>${pad(line.line, 4)} | ${line.content}</p>\n`
        })
        var uncovBranch = `<h5>Branches</h5>`
        uncoveredLinesReport[filePath].uncoveredBranches.forEach((branch) => {
            uncovBranch += `<p>${pad(branch.line, 4)} | ${branch.missing} | ${branch.content}</p>\n`
        })
        uncoveredLinesHtml += `</br><div>
        <h4>${filePath}</h4>
        ${uncovLines}
        ${uncovBranch}
        </div>`
    })
    return uncoveredLinesHtml;
}
function pad(num, size) {
    num = num.toString();
    while (num.length < size) num = "0" + num;
    return num;
}
module.exports = {
    generateHtmlReport
};

==> cobertura-diff-coverage-1.0.7.tgz: package/report.js <==

const fs = require("fs")

/**
 * generate the html report containing the dynamic scritps we need to read the json report
 *
 * @param path: string
 * @param uncoveredLinesReport: string
 */
function generateHtmlReport(path,uncoveredLinesReport) {

    const uncoveredLinesHtml = createHtmlFromJsonReport(uncoveredLinesReport)

    const reportString = `
    <!DOCTYPE html>
    <html>
    <head>
        <title> Use of JQuery to Add Edit Delete Table Row </title>
        <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.4.1/css/bootstrap.min.css">
        <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
        <script src="https://maxcdn.bootstrapcdn.com/bootstrap/3.4.1/js/bootstrap.min.js"></script>
        <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css" />
    </head>
    <body>
        <div class="container">
            <h2>Uncovered Lines and Branches</h2>
            <p class="font-weight-light">${new Date()}</p>
            <div id="uncovered">
                ${uncoveredLinesHtml}
            </div>
        </div>
    </body>
    </html>
    `
    fs.writeFileSync(path, reportString);
}

function createHtmlFromJsonReport(uncoveredLinesReport) {
    var uncoveredLinesHtml = ``
    Object.keys(uncoveredLinesReport).forEach((filePath) => {
        var uncovLines = `<h5>Lines</h5>`
        uncoveredLinesReport[filePath].uncoveredLines.forEach((line) => {
            uncovLines += `<p>${pad(line.line, 4)} | ${line.content}</p>\n`
        })
        var uncovBranch = `<h5>Branches</h5>`
        uncoveredLinesReport[filePath].uncoveredBranches.forEach((branch) => {
            uncovBranch += `<p>${pad(branch.line, 4)} | ${branch.missing} | ${branch.content}</p>\n`
        })
        uncoveredLinesHtml += `</br><div>
        <h4>${filePath}</h4>
        ${uncovLines}
        ${uncovBranch}
        </div>`
    })
    return uncoveredLinesHtml;
}
function pad(num, size) {
    num = num.toString();
    while (num.length < size) num = "0" + num;
    return num;
}
module.exports = {
    generateHtmlReport
};
